netapp_ontap.resources.auto_update_info API documentation
Description: Copyright &copy; 2026 NetApp Inc. All rights reserved …

# Module `netapp_ontap.resources.auto_update_info`

Copyright © 2026 NetApp Inc. All rights reserved.

This file has been automatically generated based on the ONTAP REST API documentation.

## Overview

The Automatic Update feature helps keep the ONTAP cluster current with the latest software component updates by automatically downloading and applying them to the cluster. By enabling this feature, you agree to the following terms:

### AUTOMATIC UPDATE TERMS

These Automatic Update Terms ("Terms") set forth the terms and conditions between NetApp, Inc., NetApp B.V., or any of their affiliates ("NetApp") and End User Customer ("Customer") in connection with the feature enabling Customer to receive software patches, upgrades, and updates to NetApp Software automatically ("Automatic Update"). By agreeing to and accepting Automatic Updates, Customer agrees to be bound by these Terms, as well as NetApp's End User License Agreement and Support Terms available at https://www.netapp.com/how-to-buy/sales-terms-and-conditions/.*
By enabling the Automatic Update feature, Customer agrees to receive Automatic Updates that NetApp may provide from time to time, without any additional notice, and NetApp will not be liable for any damages, loss of data or loss of functionalities arising from provision of Automatic Updates. Customer may revoke acceptance of these Terms and disable the receipt of Automatic Updates by setting the feature configuration to "Disabled" in ONTAP.
Timely installation of updates to security features is required for such features to function properly, including ransomware detection.*

Important note: When the automatic update feature is disabled

- No new updates are shown to the user
- All automatic updates currently scheduled will have their schedules cancelled.
- All automatic updates currently waiting for user confirmation cannot be started until the feature is re-enabled.

## Examples

### Retrieving the current status of the automatic update feature

The following example shows how to retrieve the current status of the automatic update feature:

    from netapp_ontap import HostConnection
    from netapp_ontap.resources import AutoUpdateInfo

    with HostConnection("<mgmt-ip>", username="admin", password="password", verify=False):
        resource = AutoUpdateInfo()
        resource.get()
        print(resource)

Try it out

    AutoUpdateInfo(
        {
            "_links": {"self": {}},
            "eula": {
                "accepted_timestamp": "2020-12-01T21:24:44-04:00",
                "accepted": True,
                "accepted_ip_address": "192.168.1.125",
                "user_id_accepted": "admin",
            },
            "enabled": True,
        }
    )

### Updating the status of the automatic update feature

The following example shows how to update the status of the automatic update feature:

    from netapp_ontap import HostConnection
    from netapp_ontap.resources import AutoUpdateInfo

    with HostConnection("<mgmt-ip>", username="admin", password="password", verify=False):
        resource = AutoUpdateInfo()
        resource.enabled = True
        resource.patch()

## Classes

`class AutoUpdateInfo (*args, **kwargs)`

  Allows interaction with AutoUpdateInfo objects on the host

  Initialize the instance of the resource.

  Any keyword arguments are set on the instance as properties. For example, if the class was named 'MyResource', then this statement would be true:

      MyResource(name='foo').name == 'foo'

  ## Args

  `*args`
    Each positional argument represents a parent key as used in the URL of the object. That is, each value will be used to fill in a segment of the URL which refers to some parent object. The order of these arguments must match the order they are specified in the URL, from left to right.
  `**kwargs`
    each entry will have its key set as an attribute name on the instance and its value will be the value of that attribute.

  ### Ancestors

  - Resource

  ### Methods

  `def get (self, **kwargs) -> NetAppResponse`

    Retrieves the current status of the automatic update feature and the End User License Agreement (EULA).

    ### Learn more

    - `DOC /support/auto-update`

    Fetch the details of the object from the host.

    Requires the keys to be set (if any). After returning, new or changed properties from the host will be set on the instance.

    ## Returns

    A `NetAppResponse` object containing the details of the HTTP response.

    ## Raises

    `NetAppRestError`: If the API call returned a status code >= 400 or if not all of the keys required are present and config.STRICT_GET has been set to True.

  `def patch (self, hydrate: bool = False, poll: bool = True, poll_interval: Optional[int] = None, poll_timeout: Optional[int] = None, **kwargs) -> NetAppResponse`

    Updates the current enabled status of the automatic update feature and accepts the EULA.

    ### Learn more

    - `DOC /support/auto-update`

    Send the difference in the object's state to the host as a modification request.

    Calculates the difference in the object's state since the last time we interacted with the host and sends this in the request body.

    ## Args

    `hydrate`
      If set to True, after the response is received from the call, a a GET call will be made to refresh all fields of the object.
    `poll`
      If set to True, the call will not return until the asynchronous job on the host has completed. Has no effect if the host did not return a job response.
    `poll_interval`
      If the operation returns a job, this specifies how often to query the job for updates.
    `poll_timeout`
      If the operation returns a job, this specifies how long to continue monitoring the job's status for completion.
    `connection`
      The `HostConnection` object to use for this API call. If unset, tries to use the connection which is set globally for the library or from the current context.
    `**kwargs`
      Any key/value pairs passed will normally be sent as query parameters to the host. If any of these pairs are parameters that are sent as formdata then only parameters of that type will be accepted and all others will be discarded.

    ## Returns

    A `NetAppResponse` object containing the details of the HTTP response.

    ## Raises

    `NetAppRestError`: If the API call returned a status code >= 400

  ### Inherited members

  - `Resource`:
    - `from_dict`
    - `get_collection_url`
    - `get_connection`
    - `instance_location`
    - `path_keys`
    - `poll`
    - `set_connection`
    - `to_dict`
    - `validate_schema`
`class AutoUpdateInfoSchema (*, only: types.StrSequenceOrSet | None = None, exclude: types.StrSequenceOrSet = (), many: bool | None = None, context: dict | None = None, load_only: types.StrSequenceOrSet = (), dump_only: types.StrSequenceOrSet = (), partial: bool | types.StrSequenceOrSet | None = None, unknown: str | None = None)`

  The fields of the AutoUpdateInfo object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC
  - abc.ABC

  ### Class variables

  `enabled: bool GET PATCH`

    Flag indicating feature state.

    Example: true

  `eula: AutoUpdateInfoEula GET`

    The eula field of the auto_update_info.

  `links: ApplicationNvmeAccessSubsystemMapSubsystemHostsLinks GET`

    The links field of the auto_update_info.